@@ -29,6 +29,7 @@ typedef struct {
   GSettings *settings;
 
   gchar *save_dir;
+  gchar *file_type;
   GFile *file;
 
   gboolean copy_to_clipboard;
@@ -47,7 +48,7 @@ typedef struct {
   gboolean interactive;
 } ScreenshotConfig;
 
-ScreenshotConfig *screenshot_config;
+extern ScreenshotConfig *screenshot_config;
 
 gboolean screenshot_load_config (gboolean clipboard_arg,
                                  gboolean window_arg,
