@@ -22,6 +22,13 @@
 
 #include <gtk/gtk.h>
 
+typedef enum {
+  SCREENSHOT_RESPONSE_SAVE,
+  SCREENSHOT_RESPONSE_COPY
+} ScreenshotResponse;
+
+typedef void (*SaveScreenshotCallback) (ScreenshotResponse response, gpointer *user_data);
+
 typedef struct {
   GdkPixbuf *screenshot;
   GdkPixbuf *preview_image;
@@ -29,16 +36,20 @@ typedef struct {
   GtkWidget *dialog;
   GtkWidget *save_widget;
   GtkWidget *filename_entry;
+  GtkWidget *save_button;
+  GtkWidget *copy_button;
 
   gint drag_x;
   gint drag_y;
+
+  SaveScreenshotCallback callback;
+  gpointer user_data;
 }  ScreenshotDialog;
 
-/* Keep in sync with the value defined in the UI file */
-#define SCREENSHOT_RESPONSE_COPY 1
-
-ScreenshotDialog *screenshot_dialog_new          (GdkPixbuf        *screenshot,
-						  char             *initial_uri);
+ScreenshotDialog *screenshot_dialog_new          (GdkPixbuf              *screenshot,
+						  char                   *initial_uri,
+						  SaveScreenshotCallback f,
+						  gpointer               user_data);
 
 char             *screenshot_dialog_get_uri      (ScreenshotDialog *dialog);
 char             *screenshot_dialog_get_folder   (ScreenshotDialog *dialog);
